Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Message ¶
type Message struct {
Command string `json:"command"`
Data string `json:"data"`
Args []string `json:"args"`
}
The type we use for sending messages to moshd
type Response ¶
type Response struct {
Responses []ResponseItem `json:"items"`
}
In some rare cases we need to get multiple reponses from moshd at once
func SendMessageToDaemon ¶
func (*Response) Add ¶
func (r *Response) Add(ri ResponseItem)
func (*Response) First ¶
func (r *Response) First() ResponseItem
type ResponseItem ¶
type ResponseItem struct {
Code string `json:"code"`
Message string `json:"message"`
Status string `json:"status"`
Song string `json:"song"`
Artist string `json:"artist"`
Album string `json:"album"`
CurrentTime string `json:"currenttime"`
TotalTime string `json:"totaltime"`
Image string `json:"image"`
}
The type we use for responses from moshd
Click to show internal directories.
Click to hide internal directories.